@@ -3,15 +3,19 @@ context("TEST: ensemble_model_spec()")
 resamples_tscv <- training(m750_splits) %>%
     time_series_cv(assess = "2 years", initial = "5 years", skip = "2 years", slice_limit = 1)
 
+full_resamples_tscv <- m750 %>%
+    time_series_cv(assess = "2 years", initial = "5 years", skip = "2 years", slice_limit = 1)
+
+m750_models_resample <- m750_models %>%
+    modeltime_fit_resamples(resamples_tscv, control = control_resamples(verbose = F))
 
 # TEST ENSEMBLE AVERAGE ----
 
 # No Tuning ----
 test_that("ensemble_model_spec(): Linear Regression (No Tuning)", {
 
-   ensemble_fit_lm <- m750_models %>%
+   ensemble_fit_lm <- m750_models_resample %>%
         ensemble_model_spec(
-            resamples  = resamples_tscv,
             model_spec = linear_reg() %>% set_engine("lm"),
             grid       = 3,
             control    = control_grid(verbose = TRUE)
@@ -59,14 +63,29 @@ test_that("ensemble_model_spec(): Linear Regression (No Tuning)", {
     expect_equal(nrow(forecast_tbl), 24 + n_actual)
     expect_equal(ncol(forecast_tbl), 7)
 
-    # Refit
+    # Refit - NO RESAMPLE
+
+    expect_warning({
+        # Expect warning when resamples are not provided
+        refit_tbl <- calibration_tbl %>%
+            combine_modeltime_tables(m750_models) %>%
+            modeltime_refit(m750)
+    })
+
+
+
+    # Refit - WITH RESAMPLES
+
     refit_tbl <- calibration_tbl %>%
-        modeltime_refit(m750)
+        combine_modeltime_tables(m750_models) %>%
+        modeltime_refit(m750, resamples = full_resamples_tscv, control = control_resamples(verbose = TRUE))
+
+    future_tbl <- refit_tbl %>% modeltime_forecast(h = "2 years", actual_data = m750)
+
+    expect_equal(nrow(m750) + 4*24, nrow(future_tbl) )
+
 
-    training_results_tbl <- refit_tbl %>%
-        pluck(".model", 1, "model_tbl", ".model", 1, "fit", "fit", "fit", "data")
 
-    expect_equal(nrow(training_results_tbl), nrow(m750))
 
 })
 
@@ -74,11 +93,10 @@ test_that("ensemble_model_spec(): Linear Regression (No Tuning)", {
 # Tuning ----
 test_that("ensemble_model_spec(): GLMNET (Tuning)", {
 
-
-    ensemble_fit_glmnet <- m750_models %>%
+    ensemble_fit_glmnet <- m750_models_resample %>%
         ensemble_model_spec(
-            resamples  = resamples_tscv,
-            model_spec = linear_reg(penalty = tune(), mixture = tune()) %>% set_engine("glmnet"),
+            model_spec = linear_reg(penalty = tune(), mixture = tune()) %>%
+                set_engine("glmnet"),
             grid       = 1,
             control    = control_grid(verbose = TRUE)
         )
@@ -143,7 +161,8 @@ test_that("ensemble_model_spec(): GLMNET (Tuning)", {
 
     multi_level_model_tbl <- modeltime_table(
         ensemble_fit_wt
-    )
+    ) %>%
+        combine_modeltime_tables(m750_models)
 
     accuracy_tbl <- multi_level_model_tbl %>%
         modeltime_accuracy(testing(m750_splits))
@@ -154,8 +173,8 @@ test_that("ensemble_model_spec(): GLMNET (Tuning)", {
     forecast_tbl <- refit_tbl %>%
         modeltime_forecast(h = "2 years", actual_data = m750)
 
-    expect_false(is.na(accuracy_tbl$mae))
-    expect_equal(nrow(forecast_tbl), 24 + n_actual)
+    expect_false(all(is.na(accuracy_tbl$mae)))
+    expect_equal(nrow(forecast_tbl), 24*4 + n_actual)
 
 })
 
@@ -173,37 +192,48 @@ test_that("Checks/Errors: ensemble_model_spec()", {
     # No resamples
     expect_error(ensemble_model_spec(m750_models))
 
-    # Needs 'rset'
-    expect_error({
-        m750_models %>%
-            ensemble_model_spec(resamples = 1)
-    })
-
     # Needs 'model_spec'
     expect_error({
-        m750_models %>%
-            ensemble_model_spec(
-                resamples = resamples_tscv
-            )
+        m750_models_resample %>%
+            ensemble_model_spec()
     })
 
     # Needs 'set_engine()'
     expect_error({
-        m750_models %>%
+        m750_models_resample %>%
             ensemble_model_spec(
-                resamples  = resamples_tscv,
                 model_spec = linear_reg()
             )
     })
 
     # Needs more than one model
     expect_error({
-        m750_models %>%
+        m750_models_resample %>%
             slice(1) %>%
-            ensemble_model_spec(m750_models, resamples = m750_training_resamples)
+            ensemble_model_spec(
+                model_spec = linear_reg() %>% set_engine("lm")
+            )
     })
 
 })
 
+# Checks/Errors ----
+test_that("Checks/Errors: modeltime_fit_resamples()", {
+
+    # Object is Missing
+    expect_error(modeltime_fit_resamples())
+
+    # Incorrect Object
+    expect_error(modeltime_fit_resamples(1))
+
+    # No resamples
+    expect_error(modeltime_fit_resamples(m750_models))
+
+    # Needs 'model_spec'
+    expect_error({
+        modeltime_fit_resamples(m750_models, 1)
+    })
 
 
+})
+
